@@ -26,6 +26,8 @@ def list_projects():
         l(proj[1].ljust(60), 'blue', False)
         l('*' * proj[2], 'yellow')
 
+    l('')
+
 def introduce():
     """ Welcomes a new user to the {name} tutorial."""
     config = api.get_local_config()
@@ -126,7 +128,7 @@ def next_task():
 
     task_length = len(lesson['tasks'])
     task = api.get_lrn_task()
-    if task <= task_length:
+    if task < task_length:
         api.set_lrn_task(task + 1)
         show_task()
     else:
